package sgc.portal.com.com.persistence;

import sgc.portal.base.util.EasyHashMap;
import sgc.portal.com.com.model.Comm;
import sgc.portal.com.com.model.CommDtl;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;


/**
 * 프로그램 목록 매퍼  DAO
 *
 * @author KyungHee Jang(khjang@sgc.co.kr)
 * @version 1.0.0
 * @since  2020. 8. 2.
 */


@Mapper
public interface  ComCommMngMapper {

    List<EasyHashMap<String, Object>> selectComCommMng(Comm comms);

    void insertComCommMng(Comm comms);

    void updateComCommMng(Comm comms);

    void deleteComCommMng(Comm comms);

    List<EasyHashMap<String, Object>> selectComCommDtlMng(CommDtl commdtls);

    void insertComCommDtlMng(CommDtl commdtls);

    void updateComCommDtlMng(CommDtl commdtls);

    void deleteComCommDtlMng(CommDtl commdtls);
}

